@@ -2,6 +2,7 @@ from typing import List, Any, Union, Tuple, Callable, Optional
 import torch
 import torch.nn.functional as F
 import kornia
+from fastai.vision import imagenet_stats, cifar_stats, mnist_stats
 from coreml.factory import Factory
 from coreml.utils.typing import TransformDict
 
@@ -128,6 +129,45 @@ class Resize(KorniaBase):
             kornia.geometry.transform.affwarp.Resize, size=size)
 
 
+class RandomCrop(KorniaBase):
+    """Randomly crop the given input to a particular size
+
+    Wrapper for `kornia.augmentation.RandomCrop`.
+
+    Example:
+    >>> signal = load_signal()
+    >>> signal.shape
+    (156, 156)
+    >>> t_signal = RandomCrop((128, 128))(signal)
+    >>> t_signal.shape
+    (128, 128)
+
+    :param size: desired size after resizing
+    :type size: Union[int, Tuple[int, int]]
+    :param padding: Optional padding on each border
+            of the image. Default is None, i.e no padding. If a sequence of
+            length 4 is provided, it is used to pad left, top, right,
+            bottom borders respectively. If a sequence of length 2 is provided,
+            it is used to pad left/right, top/bottom borders, respectively.
+    :type padding: Optional[Union[int, Tuple[int, int], Tuple[int, int, int, int]]]
+    :param fill: Pixel fill value for constant fill. If a tuple of
+            length 3, it is used to fill R, G, B channels respectively.
+            This value is only used when the padding_mode is constant.
+            defaults to 0.
+    :type fill: int
+    :param padding_mode: Type of padding. Should be: constant, edge, reflect or
+            symmetric. defaults to constant
+    :type padding_mode: str
+    """
+    def __init__(
+            self, size: Tuple[int, int],
+            padding: Optional[Union[int, Tuple[int, int], Tuple[int, int, int, int]]] = None,
+            fill: int = 0, padding_mode: str = 'constant'):
+        super(RandomCrop, self).__init__(
+            kornia.augmentation.RandomCrop, size=size, padding=padding,
+            fill=fill, padding_mode=padding_mode)
+
+
 class RandomAffine(KorniaBase):
     """Random affine transformation of the image keeping center invariant
 
@@ -183,16 +223,18 @@ class Normalize(KorniaBase):
 
     Wrapper for `kornia.enhance.Normalize`
 
-    :param mean: mean for each channel
-    :type mean: Union[torch.Tensor, float]
-    :param std: standard deviations for each channel
-    :type std: Union[torch.Tensor, float]
+    :param mean: mean for each channel. Also accepts string in one of
+        ['imagenet', 'cifar', 'mnist'] to use mean from those datasets
+    :type mean: Union[torch.Tensor, float, str]
+    :param std: standard deviations for each channel, Also accepts string in
+        one of ['imagenet', 'cifar', 'mnist'] to use std from those datasets
+    :type std: Union[torch.Tensor, float, str]
     :param dim: dimension along which to normalize, defaults to 0
     :type dim: int
     """
     def __init__(
-            self, mean: Union[torch.Tensor, float],
-            std: Union[torch.Tensor, float],
+            self, mean: Union[torch.Tensor, float, str],
+            std: Union[torch.Tensor, float, str],
             dim: int = 0):
         mean, std = self._check_params(mean, std)
         super(Normalize, self).__init__(
@@ -201,6 +243,14 @@ class Normalize(KorniaBase):
 
     @staticmethod
     def _check_params(mean, std):
+        if isinstance(mean, str):
+            assert mean in ['imagenet', 'cifar', 'mnist']
+            mean = eval(f'{mean}_stats')[0]
+
+        if isinstance(std, str):
+            assert std in ['imagenet', 'cifar', 'mnist']
+            std = eval(f'{std}_stats')[1]
+
         if not isinstance(mean, torch.Tensor):
             mean = torch.FloatTensor(mean)
 
@@ -280,10 +330,22 @@ class RandomErasing(KorniaBase):
     def __init__(
             self, p: float = 0.5, scale: Tuple[float, float] = (0.02, 0.33),
             ratio: Tuple[float, float] = (0.3, 3.3)):
+        self._check_params(scale, ratio)
         super(RandomErasing, self).__init__(
             kornia.augmentation.RandomErasing, p=p,
             scale=scale, ratio=ratio)
 
+    @staticmethod
+    def _check_params(scale, ratio):
+        assert isinstance(scale, (list, tuple))
+        assert isinstance(ratio, (list, tuple))
+
+        for r in ratio:
+            assert isinstance(r, float), "Requires float ratio value"
+
+        for s in scale:
+            assert isinstance(s, float), "Requires float scale value"
+
 
 class Compose:
     """Composes several transforms together to be applied on raw signal
@@ -336,6 +398,7 @@ transform_factory.register_builder('RandomVerticalFlip', RandomVerticalFlip)
 transform_factory.register_builder(
     'RandomHorizontalFlip', RandomHorizontalFlip)
 transform_factory.register_builder('RandomErasing', RandomErasing)
+transform_factory.register_builder('RandomCrop', RandomCrop)
 
 
 class ClassificationAnnotationTransform:
