@@ -16,8 +16,8 @@ class DataloaderTestCase(unittest.TestCase):
                 'python /workspace/coreml/tasks/data/classification/CIFAR10.py',
                 shell=True)
 
-    def test_classification_dataloader_2d(self):
-        """Test get_dataloader for classification with each input being 2D"""
+    def test_classification_dataloader(self):
+        """Test get_dataloader for classification"""
         cfg = {
             'root': DATA_ROOT,
             'data_type': 'image',
