@@ -28,7 +28,7 @@ class DataUtilTestCase(unittest.TestCase):
             'version': 'default',
             'mode': 'test'
         }
-        dataset_info = read_dataset_from_config(dataset_config)
+        dataset_info = read_dataset_from_config(DATA_ROOT, dataset_config)
 
         self.assertIn('file', dataset_info.keys())
         self.assertIn('label', dataset_info.keys())
